@@ -41,6 +41,12 @@
 #define HAVE_EXPLICIT_BZERO
 #define HAVE_STRNLEN
 #define explicit_bzero(a,b) SecureZeroMemory(a,b)
+#define HAS_ASN1_TIME_diff
+#define HAS_SSL_CTX_SET1_CURVES_LIST
+#define HAS_SSL_CTX_SET_MIN_PROTO_VERSION
+#define HAS_SSL_CTX_SET_SECURITY_LEVEL
+#define HAS_X509_check_host
+#define HAS_X509_get0_notAfter
 
 /* mode_t: Needed in s_conf.c for the third argument of open(3p).
  * Should be an int because of http://msdn.microsoft.com/en-us/library/z0kc8e3z(VS.71).aspx
@@ -60,13 +66,13 @@
 #define UNREAL_VERSION_GENERATION 6
 
 /* Major version number (e.g.: 2 for Unreal3.2*) */
-#define UNREAL_VERSION_MAJOR 1
+#define UNREAL_VERSION_MAJOR 2
 
 /* Minor version number (e.g.: 1 for Unreal3.2.1) */
-#define UNREAL_VERSION_MINOR 8
+#define UNREAL_VERSION_MINOR 0
 
 /* Version suffix such as a beta marker or release candidate marker. (e.g.:
    -rcX for unrealircd-3.2.9-rcX) */
-#define UNREAL_VERSION_SUFFIX ".1"
+#define UNREAL_VERSION_SUFFIX ".2"
 
 #endif
